@@ -118,6 +118,14 @@ class Script(default.Script):
             orca.setLocusOfFocus(event, event.source)
             return
 
+        # Unfiled, but yet another case of only getting a focus: event.
+        # Seems to happen mainly when selecting.
+        if role == pyatspi.ROLE_ICON:
+            topLevelObject = self.utilities.topLevelObject(event.source)
+            if topLevelObject == orca_state.activeWindow:
+                orca.setLocusOfFocus(event, event.source)
+                return
+
         # Unfiled, but yet another case of only getting a focus: event when
         # a widget appears in a parent container and is already focused.
         if role == pyatspi.ROLE_TABLE:
@@ -129,6 +137,21 @@ class Script(default.Script):
             orca.setLocusOfFocus(event, obj)
             return
 
+    def onRowReordered(self, event):
+        """Callback for object:row-reordered accessibility events."""
+
+        # We're seeing a crazy ton of these emitted bogusly.
+        pass
+
+    def onSelectionChanged(self, event):
+        """Callback for object:selection-changed accessibility events."""
+
+        if event.source.getRole() == pyatspi.ROLE_LAYERED_PANE \
+           and self.utilities.selectedChildCount(event.source) > 1:
+            return
+
+        super().onSelectionChanged(event)
+
     def onTextSelectionChanged(self, event):
         """Callback for object:text-selection-changed accessibility events."""
 
